Name:           ocaml-cryptokit
Version:        1.9
Release:        %mkrel 2
Summary:        OCaml library of cryptographic and hash functions
License:        LGPLv2 with linking exception
Group:          Development/OCaml
URL:            http://forge.ocamlcore.org/projects/cryptokit/
Source0:        http://forge.ocamlcore.org/frs/download.php/1229/cryptokit-%{version}.tar.gz

BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-findlib
BuildRequires:  zlib-devel
BuildRequires:  ncurses-devel

%description
The Cryptokit library for Objective Caml provides a variety of
cryptographic primitives that can be used to implement cryptographic
protocols in security-sensitive applications. The primitives provided
include:

* Symmetric-key cryptography: AES, DES, Triple-DES, ARCfour, in ECB,
  CBC, CFB and OFB modes.
* Public-key cryptography: RSA encryption and signature; Diffie-Hellman
  key agreement.
* Hash functions and MACs: SHA-1, SHA-256, RIPEMD-160, MD5, and MACs
  based on AES and DES.
* Random number generation.
* Encodings and compression: base 64, hexadecimal, Zlib compression. 

Additional ciphers and hashes can easily be used in conjunction with
the library. In particular, basic mechanisms such as chaining modes,
output buffering, and padding are provided by generic classes that can
easily be composed with user-provided ciphers. More generally, the
library promotes a "Lego"-like style of constructing and composing
transformations over character streams.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       zlib-devel

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n cryptokit-%{version}

%build
ocaml setup.ml -debug -configure --libdir %{_libdir}
ocaml setup.ml -build

%check
# This opens /dev/random but never reads from it.
ocaml setup.ml -test

%install
rm -rf %{buildroot}
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR
mkdir -p %{buildroot}%{_libdir}/ocaml/cryptokit
mkdir -p %{buildroot}%{_libdir}/ocaml/stublibs
ocaml setup.ml -debug -install 

%files
%doc README.txt LICENSE.txt AUTHORS.txt Changes
%dir %{_libdir}/ocaml/cryptokit
%{_libdir}/ocaml/cryptokit/META
%{_libdir}/ocaml/cryptokit/*.cma
%{_libdir}/ocaml/cryptokit/*.cmi
%{_libdir}/ocaml/cryptokit/*.cmxs
%{_libdir}/ocaml/stublibs/*.so*

%files devel
%{_libdir}/ocaml/cryptokit/*.a
%{_libdir}/ocaml/cryptokit/*.cmxa
%{_libdir}/ocaml/cryptokit/*.cmx
%{_libdir}/ocaml/cryptokit/*.mli


%changelog
* Sat Oct 19 2013 umeabot <umeabot> 1.9-2.mga4
+ Revision: 534958
- Mageia 4 Mass Rebuild

* Mon Sep 16 2013 malo <malo> 1.9-1.mga4
+ Revision: 480292
- update to 1.9

* Tue Sep 10 2013 blue_prawn <blue_prawn> 1.6-7.mga4
+ Revision: 477220
- rebuild for ocaml-4.01.0

* Sat Jan 12 2013 umeabot <umeabot> 1.6-6.mga3
+ Revision: 361252
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 malo <malo> 1.6-5.mga3
+ Revision: 324104
- rebuild for new ocaml

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.6-4.mga3
+ Revision: 301442
- build requires ocaml-compiler
- rebuild for ocaml-4.00.0
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.6-2.mga3
+ Revision: 300059
- new rpm group for ocaml

* Mon Jun 25 2012 blue_prawn <blue_prawn> 1.6-1.mga3
+ Revision: 263592
- updated to last version 1.6

* Mon Apr 09 2012 malo <malo> 1.5-2.mga2
+ Revision: 229843
- adding missing requires to zlib-devel

* Sun Oct 23 2011 malo <malo> 1.5-1.mga2
+ Revision: 157506
- missing Buildrequires on ncurses-devel
- missing BuildRequires to ocaml-findlib
- removing BuildRoot and unused BuildRequires
- imported package ocaml-cryptokit


* Sat Jun 27 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.3-2mdv2010.0
+ Revision: 390038
- rebuild

* Thu Jun 11 2009 Florent Monnier <blue_prawn@mandriva.org> 1.3-1mdv2010.0
+ Revision: 385289
- import ocaml-cryptokit


